Visualisator = {
    display: null,
    pictures: [],
    maxWidth: 0,
    loadedImages: 0,
    pictureRatio: 0,

    init: function () {
        this.display = document.querySelector('.display');
        list = document.querySelector('nav ul');
        i = 1;

        structure.nodes.forEach(node => {
            var img = document.createElement('img');

            img.onload = loadedImg => {
                if (loadedImg.target.naturalWidth > this.maxWidth) this.maxWidth = loadedImg.target.naturalWidth;

                this.pictures.push(img);

                Visualisator.preparePictures();
            }

            img.src = 'sprites/' + node.name;
            img.style.zIndex = node.z;
            img.dataset.left = node.position[0];
            img.dataset.top = node.position[1];

            this.display.appendChild(img);

            var li = document.createElement('li');
            li.innerText = node.name.substring(0, node.name.indexOf('.'));
            li.dataset.number = i;
            li.onclick = function(e) {
                Visualisator.toggleElement(this);
            }

            if (i != structure.nodes.length) this.toggleElement(li);

            if (node.persist !== true) {
                list.appendChild(li);
            } else {
                img.style.display = 'initial';
            }

            i++;
        });
    },

    toggleElement: function (li) {
        var img = Visualisator.display.querySelector('img:nth-child(' + li.dataset.number + ')');
        if (img.style.display == 'none') {
            li.classList.remove('disabled');
            img.style.display = 'initial';
        } else {
            li.classList.add('disabled');
            img.style.display = 'none';
        }
    },

    preparePictures: function () {
        var pictures = this.display.querySelectorAll('img');

        pictures.forEach(picture => {
            if (picture.naturalWidth == this.maxWidth) {
                this.pictureRatio = picture.naturalWidth / picture.naturalHeight;
            }
        });

        pictures.forEach(picture => {
            picture.style.width = String(picture.naturalWidth * 100 / this.maxWidth) + '%';
            picture.style.left = String(picture.dataset.left * 100 / this.maxWidth) + '%';
            picture.style.top = String((picture.dataset.top * 100 / this.maxWidth) * this.pictureRatio) + '%';

            this.setDisplaySize();
            i++;
        })
    },

    setDisplaySize: function() {
        var screenRatio = document.body.clientWidth / document.body.clientHeight;

        if (screenRatio > this.pictureRatio) {
            this.display.style.paddingTop = null;
            this.display.style.height = '100%';
            this.display.style.width = (100/screenRatio*this.pictureRatio) + '%';
        } else {
            this.display.style.height = null;
            this.display.style.width = '100%';
            this.display.style.paddingTop = (100/this.pictureRatio) + '%';
        }
    }
}

document.addEventListener("DOMContentLoaded", e => {
    Visualisator.init();
});

window.addEventListener('resize', e => {
    Visualisator.setDisplaySize()
});